/v1/projects/{project_id}/iou/vms — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/iou/vms

Contents

- /v1/projects/{project_id}/iou/vms
  - POST /v1/projects/{project_id}/iou/vms
    - Parameters
    - Response status codes
    - Input
    - Output

## POST /v1/projects/{project_id}/iou/vms

Create a new IOU instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
ethernet_adapters |  | integer | How many ethernet adapters are connected to the IOU
initial_config |  | ['string', 'null'] | Initial configuration of the IOU
iourc_path |  | string | Path of iourc
l1_keepalives |  | ['boolean', 'null'] | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram |  | ['integer', 'null'] | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
ram |  | ['integer', 'null'] | Allocated RAM MB
serial_adapters |  | integer | How many serial adapters are connected to the IOU
vm_id |  |  | IOU VM identifier

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »